deltona
=======

.. include:: badges.rst

A lot of uncategorised utilities.

.. toctree::
   :caption: Administration Commands
   :glob:
   :hidden:

   commands/admin/*

.. toctree::
   :caption: Desktop Environment Commands
   :glob:
   :hidden:

   commands/desktop/*

.. toctree::
   :caption: Git Commands
   :glob:
   :hidden:

   commands/git/*

.. toctree::
   :caption: Media Commands
   :glob:
   :hidden:

   commands/media/*

.. toctree::
   :caption: Miscellaneous Commands
   :glob:
   :hidden:

   commands/misc/*

.. toctree::
   :caption: String-Related Commands
   :glob:
   :hidden:

   commands/string/*

.. toctree::
   :caption: Wine Commands
   :glob:
   :hidden:

   commands/wine/*

.. toctree::
   :caption: WWW Commands
   :glob:
   :hidden:

   commands/www/*

.. only:: html

   .. toctree::
      :caption: Library
      :glob:
      :hidden:
      :maxdepth: 1

      library/*

   Indices and tables
   ==================
   * :ref:`genindex`
   * :ref:`modindex`
